@@ -1,6 +1,6 @@
-#' get/set encoding slot of an object
+#' Get and set encoding.
 #' 
-#' Method for partition, partitionBundle objects.
+#' Method for \code{textstat} objects and classes inheriting from \code{textstat}.
 #' 
 #' @param object the object with an 'encoding'-slot
 #' @param value value to be assigned
@@ -12,7 +12,7 @@ setGeneric("encoding", function(object) standardGeneric("encoding"))
 setGeneric("encoding<-", function(object, value) standardGeneric("encoding<-"))
 
 #' @rdname encoding
-setMethod("encoding", "partition", function(object) object@encoding)
+setMethod("encoding", "textstat", function(object) object@encoding)
 
 #' @rdname encoding
-setMethod("encoding", "partitionBundle", function(object) object@encoding)
+setMethod("encoding", "bundle", function(object) object@encoding)
