@@ -9,7 +9,6 @@ NULL
 #' @param object a partition, partitionBundle or comp object
 #' @param size logical
 #' @param pAttribute character vector
-#' @param meta character vector
 #' @param verbose logical
 #' @param mc logical or, if numeric, providing the number of cores
 #' @param ... further parameters
@@ -24,7 +23,7 @@ setGeneric("enrich", function(object, ...){standardGeneric("enrich")})
 #' @exportMethod enrich
 #' @docType methods
 #' @rdname enrich-method
-setMethod("enrich", "partition", function(object, size = FALSE, pAttribute = NULL, id2str = TRUE, meta = NULL, verbose = TRUE, mc=FALSE, ...){
+setMethod("enrich", "partition", function(object, size = FALSE, pAttribute = NULL, id2str = TRUE, verbose = TRUE, mc=FALSE, ...){
   if (size) object@size <- size(object)
   if (!is.null(pAttribute)) {
     stopifnot(is.character(pAttribute) == TRUE, length(pAttribute) <= 2, all(pAttribute %in% pAttributes(object)))
@@ -32,13 +31,9 @@ setMethod("enrich", "partition", function(object, size = FALSE, pAttribute = NUL
       message = paste('getting counts for p-attribute(s):', paste(pAttribute, collapse = ", "), sep = " "),
       verbose = verbose
       )  
-    object@stat <- count(.Object = object, pAttribute = pAttribute, id2str = id2str, mc = mc)
+    object@stat <- count(.Object = object, pAttribute = pAttribute, id2str = id2str, mc = mc, verbose = verbose)
     object@pAttribute <- pAttribute
   }
-  if (!is.null(meta)) {
-    .verboseOutput(message = 'setting up metadata (table and list of values)', verbose = verbose)
-    object@metadata <- meta(object, sAttributes = meta)
-  }
   object
 })
 
@@ -59,7 +54,7 @@ setMethod("enrich", "kwic", function(object, meta = NULL){
         cposToGet <- object@cpos[which(object@cpos[["position"]] == 0)][, .SD[1], by = "hit_no", with = TRUE][["cpos"]]
         # cposToGet <- object@cpos[hit_no %in% object@table[["hit_no"]] ]  [position == 0][, .SD[1], by = hit_no][["cpos"]]
         strucs <- CQI$cpos2struc(object@corpus, metadat, cposToGet)
-        as.utf8(CQI$struc2str(object@corpus, metadat, strucs))
+        as.nativeEnc(CQI$struc2str(object@corpus, metadat, strucs), from = object@encoding)
       }
     )
     metainformation <- data.frame(metainformation, stringsAsFactors = FALSE)
