@@ -24,11 +24,11 @@ NULL
 #' @examples
 #' \dontrun{
 #'   use("polmineR.sampleCorpus")
-#'   bt2009 <- partition("PLPRBTTXT", text_year="2009")
-#'   pBundle <- partitionBundle(bt2009, sAttribute="text_date", progress=TRUE, pAttribute="word")
-#'   dtm <- as.DocumentTermMatrix(pBundle, col="count")
+#'   bt2009 <- partition("PLPRBTTXT", text_year = "2009")
+#'   pBundle <- partitionBundle(bt2009, sAttribute = "text_date", progress = TRUE, pAttribute = "word")
+#'   dtm <- as.DocumentTermMatrix(pBundle, col = "count")
 #'   summary(pBundle)
-#'   btBundle <- partitionBundle("PLPRBTTXT", sAttribute="text_date")
+#'   btBundle <- partitionBundle("PLPRBTTXT", sAttribute = "text_date")
 #' }
 #' @seealso \code{\link{partition}} and \code{\link{bundle-class}}
 setGeneric("partitionBundle", function(.Object, ...) standardGeneric("partitionBundle"))
@@ -55,21 +55,21 @@ setMethod("partitionBundle", "partition", function(
     progress=progress, verbose=verbose,  mc=mc,
     ...
   )
-  names(bundle@objects) <- paste(adjustEncoding(prefix, bundle@encoding), values, sep='')
+  names(bundle@objects) <- paste(as.corpusEnc(prefix, corpusEnc = bundle@encoding), values, sep='')
   bundle
 })
 
 
 #' @rdname partitionBundle-method
 setMethod("partitionBundle", "character", function(
-  .Object, sAttribute, values=NULL, prefix=c(""),
+  .Object, sAttribute, values = NULL, prefix = c(""),
   mc = getOption("polmineR.mc"), verbose = TRUE, progress = FALSE,
   ...
 ) {
   bundle <- new(
     "partitionBundle",
     corpus = .Object, encoding = RegistryFile$new(.Object)$getEncoding(),
-    call=deparse(match.call())
+    call = deparse(match.call())
   )
   strucs <- c(0:(CQI$attribute_size(.Object, sAttribute, "s") - 1))
   if (!is.null(values)) {
@@ -80,17 +80,17 @@ setMethod("partitionBundle", "character", function(
     values <- CQI$struc2str(.Object, sAttribute, strucs)
   }
   cposMatrix <- do.call(rbind, lapply(strucs, function(x) CQI$struc2cpos(.Object, sAttribute, x)))
-  cposList <- split(cposMatrix, f=values)
-  cposList <- lapply(cposList, function(x) matrix(x, ncol=2))
+  cposList <- split(cposMatrix, f = values)
+  cposList <- lapply(cposList, function(x) matrix(x, ncol = 2))
   
   if (verbose) message("... generating the partitions")
   .makeNewPartition <- function(x, corpus, encoding, sAttribute, ...){
     newPartition <- new(
       "partition",
-      corpus=corpus, encoding=encoding,
-      stat=data.table(),
-      cpos=x, size=sum(apply(x,1,function(row) row[2] - row[1] + 1)),
-      sAttributeStrucs=sAttribute
+      corpus = corpus, encoding = encoding,
+      stat = data.table(),
+      cpos = x, size = sum(apply(x,1,function(row) row[2] - row[1] + 1)),
+      sAttributeStrucs = sAttribute
     )
     newPartition@strucs <- CQI$cpos2struc(.Object, sAttribute, x[,1])
     newPartition
@@ -101,6 +101,7 @@ setMethod("partitionBundle", "character", function(
     mc = mc, progress = progress, verbose = verbose, ...
     )
   for (i in c(1:length(bundle))) bundle@objects[[i]]@name <- names(cposList)[i]
+  for (i in c(1:length(bundle))) bundle@objects[[i]]@sAttributes <- setNames(list(names(cposList)[i]), sAttribute) 
   names(bundle@objects) <- names(cposList)
   bundle
 })
@@ -115,19 +116,19 @@ setMethod("as.partitionBundle", "list", function(.Object, ...){
 
 #' @exportMethod as.partitionBundle
 #' @rdname partitionBundle-method
-setMethod("partitionBundle", "context", function(.Object, mc=getOption("polmineR.mc"), verbose=FALSE, progress=TRUE){
+setMethod("partitionBundle", "context", function(.Object, mc = getOption("polmineR.mc"), verbose = FALSE, progress = TRUE){
   newPartitionBundle <- new(
     "partitionBundle",
-    corpus=.Object@corpus, encoding=.Object@encoding,
-    explanation="this partitionBundle is derived from a context object"
+    corpus = .Object@corpus, encoding = .Object@encoding,
+    explanation = "this partitionBundle is derived from a context object"
   )
   .makeNewPartition <- function(cpos, contextObject, ...){
     newPartition <- new(
       "partition",
-      corpus=contextObject@corpus,
-      encoding=contextObject@encoding,
-      cpos=matrix(c(cpos[["left"]][1], cpos[["right"]][length(cpos[["right"]])]), ncol=2),
-      stat=data.table()
+      corpus = contextObject@corpus,
+      encoding = contextObject@encoding,
+      cpos = matrix(c(cpos[["left"]][1], cpos[["right"]][length(cpos[["right"]])]), ncol=2),
+      stat = data.table()
     )
     newPartition <- enrich(newPartition, size=TRUE, pAttribute=contextObject@pAttribute, verbose=verbose)
     newPartition@strucs <- c(
